/**
 * Implement Gatsby's Node APIs in this file.
 *
 * See: https://www.gatsbyjs.org/docs/node-apis/
 */


const path = require(`path`);

const makeRequest = (graphql, request) => new Promise((resolve, reject) => {
  resolve(
    graphql(request).then(result => {
      if (result.errors) {
        reject(result.errors)
      }

      return result;
    })
  )
});


exports.createPages = ({ actions, graphql }) => {
  const { createPage } = actions;

  const getDomains = makeRequest(graphql, `
    {
      allStrapiDomain {
        edges {
          node {
            id
            slug
          }
        }
      }

      allStrapiUseCase {
        edges {
          node {
            id
            slug
          }
        }
      }

      allStrapiArticle {
        edges {
          node {
            id
            slug
          }
        }
      }

      allStrapiPublicationSection {
        edges {
          node {
            slug
            title
            body
            nav_links {
              prev
              next
            }

            publication {
              slug
              title
              introduction
              nav_links {
                next
              }
            }

            publication_pages {
              slug
              title
              author
              body
              notes
              references
              page_parts {
                title
                body
              }
              links {
                title
                description
                buttonLabel
                url
              }
              nav_links {
                prev
                next
              }
            }
          }
        }
      }
    }
  `).then(result => {

    result.data.allStrapiDomain.edges.forEach(({ node }) => {
      createPage({
        path: `/domains/${node.slug}`,
        component: path.resolve(`src/templates/domain.js`),
        context: {
          id: node.id,
        },
      })
    })

    result.data.allStrapiUseCase.edges.forEach(({ node }) => {
      createPage({
        path: `/use-cases/${node.slug}`,
        component: path.resolve(`src/templates/use-case.js`),
        context: {
          id: node.id,
        },
      })
    })

    result.data.allStrapiArticle.edges.forEach(({ node }) => {
      createPage({
        path: `/articles/${node.slug}`,
        component: path.resolve(`src/templates/article.js`),
        context: {
          id: node.id,
        },
      })
    })


    const publications = {}
    result.data.allStrapiPublicationSection.edges.forEach(({ node }) => {

      if(!publications.hasOwnProperty(node.publication.slug)) {
        publications[node.publication.slug] = {
          ...node.publication
        }
      }

      if(!publications[node.publication.slug]['sections']) {
        publications[node.publication.slug]['sections'] = []
      }

      publications[node.publication.slug]['sections'].push({
        slug: node.slug,
        title: node.title,
        body: node.body,
        pages: node.publication_pages,
        nav_links: node.nav_links
      })
    });

    Object.keys(publications).forEach((slug) => {
      //console.log("slug: " + slug)
      createPage({
        path: `/${slug}/`,
        component: path.resolve(`src/templates/publication.js`),
        context: {
          publication: publications[slug]
        },
      })
    })

  });

  return getDomains;
};